@@ -88,6 +88,7 @@ ggplotly.ggmatrix <- function(p = ggplot2::last_plot(), width = NULL,
                               height = NULL, tooltip = "all", dynamicTicks = FALSE, 
                               layerData = 1, originalData = TRUE, source = "A", ...) {
   dots <- list(...)
+
   # provide a sensible crosstalk if none is already provided (makes ggnostic() work at least)
   if (!crosstalk_key() %in% names(p$data)) {
     p$data[[crosstalk_key()]] <- p$data[[".rownames"]] %||% seq_len(nrow(p$data))
@@ -180,8 +181,8 @@ gg2list <- function(p, width = NULL, height = NULL,
     grDevices::png
   } else if (capabilities("jpeg")) {
     grDevices::jpeg 
-  } else if (system.file(package = "Cairo") != "") {
-    Cairo::Cairo
+  } else if (is_installed("Cairo")) {
+    function(filename, ...) Cairo::Cairo(file = filename, ...)
   } else {
     stop(
       "No Cairo or bitmap device is available. Such a graphics device is required to convert sizes correctly in ggplotly().\n\n", 
@@ -197,7 +198,7 @@ gg2list <- function(p, width = NULL, height = NULL,
     height <- height %||% default(grDevices::dev.size("px")[2])
   }
   # open the device and make sure it closes on exit
-  dev_fun(file = tempfile(), width = width %||% 640, height = height %||% 480)
+  dev_fun(filename = tempfile(), width = width %||% 640, height = height %||% 480)
   on.exit(grDevices::dev.off(), add = TRUE)
   
   # check the value of dynamicTicks
@@ -242,7 +243,7 @@ gg2list <- function(p, width = NULL, height = NULL,
     # currently, LayerSf is the only core-ggplot2 Layer that makes use
     # of it https://github.com/tidyverse/ggplot2/pull/2875#issuecomment-438708426
     data <- layer_data
-    if (packageVersion("ggplot2") > "3.1.0") {
+    if (get_package_version("ggplot2") > "3.1.0") {
       data <- by_layer(function(l, d) if (is.function(l$setup_layer)) l$setup_layer(d, plot) else d)
     }
     
@@ -303,6 +304,14 @@ gg2list <- function(p, width = NULL, height = NULL,
       d[["y_plotlyDomain"]] <- d[["y"]]
       d
     })
+    # And since we're essentially adding an "unknown" (to ggplot2) 
+    # aesthetic, add it to the dropped_aes field to avoid fals positive
+    # warnings (https://github.com/tidyverse/ggplot2/pull/4866)
+    layers <- lapply(layers, function(l) {
+      l$stat$dropped_aes <- c(l$stat$dropped_aes, "x_plotlyDomain")
+      l$stat$dropped_aes <- c(l$stat$dropped_aes, "y_plotlyDomain")
+      l
+    })
     
     # Transform all scales
     data <- lapply(data, ggfun("scales_transform_df"), scales = scales)
@@ -422,6 +431,11 @@ gg2list <- function(p, width = NULL, height = NULL,
       x <- reComputeGroup(x, z)
       # dplyr issue??? https://github.com/tidyverse/dplyr/issues/2701
       attr(y$group, "n") <- NULL
+      # https://github.com/plotly/plotly.R/issues/2013
+      if (!identical(class(x$group), class(y$group))) {
+        x$group <- as.character(x$group)
+        y$group <- as.character(y$group)
+      }
       suppressMessages(dplyr::left_join(x, y))
     }, data, nestedKeys, layers)
     
@@ -670,9 +684,10 @@ gg2list <- function(p, width = NULL, height = NULL,
           d$y <- scales::rescale(d$y, rng$y_range, from = c(0, 1))
           params <- list(
             colour = panelGrid$colour, 
-            size = panelGrid$size, 
             linetype = panelGrid$linetype
           )
+          nm <- linewidth_or_size(panelGrid)
+          params[[nm]] <- panelGrid[[nm]]
           grill <- geom2trace.GeomPath(d, params)
           grill$hoverinfo <- "none"
           grill$showlegend <- FALSE
@@ -717,8 +732,12 @@ gg2list <- function(p, width = NULL, height = NULL,
       isDiscrete <- identical(sc$scale_name, "position_d")
       isDiscreteType <- isDynamic && isDiscrete
       
-      ticktext <- rng[[xy]]$get_labels %()% rng[[paste0(xy, ".labels")]]
-      tickvals <- rng[[xy]]$break_positions %()% rng[[paste0(xy, ".major")]]
+      # In 3.2.x .major disappeared in favor of break_positions()
+      # (tidyverse/ggplot2#3436), but with 3.4.x break_positions() no longer
+      # yields the actual final positions on a 0-1 scale, but .major does
+      # (tidyverse/ggplot2#5029)
+      ticktext <- rng[[paste0(xy, ".labels")]] %||% rng[[xy]]$get_labels()
+      tickvals <- rng[[paste0(xy, ".major")]] %||% rng[[xy]]$break_positions()
       
       # https://github.com/tidyverse/ggplot2/pull/3566#issuecomment-565085809
       hasTickText <- !(is.na(ticktext) | is.na(tickvals))
@@ -729,7 +748,7 @@ gg2list <- function(p, width = NULL, height = NULL,
         # TODO: log type?
         type = if (isDateType) "date" else if (isDiscreteType) "category" else "linear",
         autorange = isDynamic,
-        range = rng[[paste0(xy, ".range")]] %||% rng[[paste0(xy, "_range")]],
+        range = rng[[xy]]$dimension %()% rng[[paste0(xy, ".range")]] %||% rng[[paste0(xy, "_range")]],
         tickmode = if (isDynamic) "auto" else "array",
         ticktext = ticktext,
         tickvals = tickvals,
@@ -952,7 +971,10 @@ gg2list <- function(p, width = NULL, height = NULL,
   gglayout$legend <- list(
     bgcolor = toRGB(theme$legend.background$fill),
     bordercolor = toRGB(theme$legend.background$colour),
-    borderwidth = unitConvert(theme$legend.background$size, "pixels", "width"),
+    borderwidth = unitConvert(
+      theme$legend.background[[linewidth_or_size(theme$legend.background)]], 
+      "pixels", "width"
+    ),
     font = text2font(theme$legend.text)
   )
   
@@ -1185,7 +1207,7 @@ verifyUnit <- function(u) {
   
   ## the default unit in ggplot2 is millimeters (unless it's element_text())
   if (inherits(u, "element")) {
-    grid::unit(u$size %||% 0, "points")
+    grid::unit(u[[linewidth_or_size(u)]] %||% 0, "points")
   } else {
     grid::unit(u %||% 0, "mm")
   }
@@ -1384,10 +1406,13 @@ gdef2trace <- function(gdef, theme, gglayout) {
     rng <- range(gdef$bar$value)
     gdef$bar$value <- scales::rescale(gdef$bar$value, from = rng)
     gdef$key$.value <- scales::rescale(gdef$key$.value, from = rng)
+    vals <- lapply(gglayout[c("xaxis", "yaxis")], function(ax) {
+      if (identical(ax$tickmode, "auto")) ax$ticktext else ax$tickvals
+    })
     list(
-      x = with(gglayout$xaxis, if (identical(tickmode, "auto")) ticktext else tickvals)[[1]],
-      y = with(gglayout$yaxis, if (identical(tickmode, "auto")) ticktext else tickvals)[[1]],
-      # esentially to prevent this getting merged at a later point
+      x = vals[[1]][[1]],
+      y = vals[[2]][[1]],
+      # essentially to prevent this getting merged at a later point
       name = gdef$hash,
       type = "scatter",
       mode = "markers",
@@ -1402,7 +1427,8 @@ gdef2trace <- function(gdef, theme, gglayout) {
           bgcolor = toRGB(theme$legend.background$fill),
           bordercolor = toRGB(theme$legend.background$colour),
           borderwidth = unitConvert(
-            theme$legend.background$size, "pixels", "width"
+            theme$legend.background[[linewidth_or_size(theme$legend.background)]],
+            "pixels", "width"
           ),
           thickness = unitConvert(
             theme$legend.key.width, "pixels", "width"
