@@ -8,7 +8,7 @@
 #' @param p a ggplot object, or a plotly object, or a list.
 #' @param registerFrames should a frame trace attribute be interpreted as frames in an animation?
 #' @export
-#' @examples
+#' @examplesIf interactive() || !identical(.Platform$OS.type, "windows")
 #'
 #' p <- plot_ly(economics, x = ~date, y = ~pce)
 #' # the unevaluated plotly object
@@ -425,7 +425,10 @@ registerFrames <- function(p, frameMapping = NULL) {
   # remove frames from the trace names
   for (i in seq_along(p$x$data)) {
     tr <- p$x$data[[i]]
-    if (length(tr[["name"]]) != 1) next
+    if (length(tr[["name"]]) != 1) {
+      p$x$data[[i]]$frameOrder <- NULL
+      next
+    } 
     nms <- strsplit(as.character(tr[["name"]]), br())[[1]]
     idx <- setdiff(seq_along(nms), tr$frameOrder %||% 0)
     p$x$data[[i]]$name <- if (length(idx)) paste(nms[idx], collapse = br()) else NULL
@@ -481,12 +484,14 @@ registerFrames <- function(p, frameMapping = NULL) {
     d <- lapply(d, function(tr) { tr$visible <- tr$visible %||% TRUE; tr })
     
     # if this frame is missing a trace name, supply an invisible one
-    traceNamesMissing <- setdiff(frameTraceNames, sapply(d, "[[", "name"))
+    traceNamesMissing <- setdiff(frameTraceNames, unlist(lapply(d, "[[", "name")))
     for (j in traceNamesMissing) {
       idx <- vapply(p$x$data, function(tr) isTRUE(tr[["name"]] == j), logical(1))
-      idx <- which(idx)[[1]]
-      invisible <- modify_list(p$x$data[[idx]], list(visible = FALSE))
-      d <- c(d, list(invisible))
+      if (any(idx)){
+        idx <- which(idx)[[1]]
+        invisible <- modify_list(p$x$data[[idx]], list(visible = FALSE))
+        d <- c(d, list(invisible))
+      }
     }
     p$x$frames[[i]] <- list(
       name = as.character(format(nm)),
@@ -668,6 +673,8 @@ map_size <- function(traces, stroke = FALSE) {
 }
 
 # appends a new (empty) trace to generate (plot-wide) colorbar/colorscale
+#' @importFrom rlang is_na
+#
 map_color <- function(traces, stroke = FALSE, title = "", colorway, na.color = "transparent") {
   color <- if (stroke) {
     lapply(traces, function(x) { x[["stroke"]] %||% x[["color"]] })
@@ -738,7 +745,7 @@ map_color <- function(traces, stroke = FALSE, title = "", colorway, na.color = "
         if (!has_attr(type, attr)) next
         if (is_colorway && "textfont" == attr) next
         col <- if (isSingular) rgba_ else if (array_ok(attrs[[attr]]$color)) rgba else NA
-        if (is.na(col)) {
+        if (is_na(col)) {
           warning("`", attr, ".color` does not currently support multiple values.", call. = FALSE)
         } else {
           trace[[attr]] <- modify_list(list(color = default_(col)), trace[[attr]])
@@ -754,7 +761,7 @@ map_color <- function(traces, stroke = FALSE, title = "", colorway, na.color = "
       } else if (has_attr(type, "line")) {
         # if fill does not exist, 'color' controls line.color
         col <- if (isSingular) rgba_ else if (array_ok(attrs$line$color)) rgba else NA
-        if (is.na(col)) {
+        if (is_na(col)) {
           warning("`line.color` does not currently support multiple values.", call. = FALSE)
         } else {
           trace[["line"]] <- modify_list(list(color = default_(col)), trace[["line"]])
