@@ -1,6 +1,3 @@
-context("Contour")
-
-
 
 test_that("geom_contour is translated to a path", {
   skip_if_not_installed("reshape2")
@@ -9,7 +6,7 @@ test_that("geom_contour is translated to a path", {
   names(volcano3d) <- c("x", "y", "z")
   # Draw a contour plot using geom_contour
   gg <- ggplot(volcano3d) + geom_contour(aes(x=x, y=y, z=z))
-  L <- save_outputs(gg, "contour")
+  L <- expect_doppelganger_built(gg, "contour")
   expect_equivalent(length(L$data), 1)
   expect_identical(L$data[[1]]$type, "scatter")
   expect_identical(L$data[[1]]$mode, "lines")
