@@ -1,4 +1,4 @@
-context("lines")
+
 
 test_that("6 different automatic lty converted to plotly's 6 types", {
   d <- expand.grid(x=1:6, y=1:6)
@@ -41,7 +41,19 @@ test_that("different colored lines become different colored traces", {
   expect_identical(info$data[[2]]$x[1:n], x)
 })
 
-
+test_that("Milliseconds are preserved with dynamic ticks", {
+  d <- data.frame(
+    t = as.POSIXct("1970-01-01 00:00") + (0:999) / 10,
+    y = sin((0:999) * 4 * pi / 1000)
+  )
+  gg <- ggplot(d, aes(t, y)) + geom_line()
+  p <- ggplotly(gg, dynamicTicks = TRUE)
+  j <- plotly_json(p, jsonedit = FALSE)
+  t2 <- jsonlite::fromJSON(j)$data$x[[1]] %>% 
+    as.POSIXct(format = "%Y-%m-%d %H:%M:%OS")
+  expect_equal(as.numeric(mean(diff(t2))), 0.1, tolerance = 0.01)
+  expect_doppelganger_built(p, "line-milliseconds")
+})
 
 test_that("Translates both dates and datetimes (with dynamic ticks) correctly", {
   
