@@ -1,4 +1,3 @@
-context("ggplot ylim")
 
 # http://www.cookbook-r.com/Graphs/Bar_and_line_graphs_%28ggplot2%29/
 
@@ -16,7 +15,7 @@ gg.ylim <-
 
 expect_traces <- function(gg, n.traces, name){
   stopifnot(is.numeric(n.traces))
-  L <- save_outputs(gg, paste0("ylim-", name))
+  L <- expect_doppelganger_built(gg, paste0("ylim-", name))
   all.traces <- L$data
   no.data <- sapply(all.traces, function(tr) {
     is.null(tr[["x"]]) && is.null(tr[["y"]])
